==> haskell-unexceptionalio-0.5.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unexceptionalio
version:              0.5.1
visibility:           public
id:                   unexceptionalio-0.5.1-IZ96mLUOMuXAaGSDZxlxw
key:                  unexceptionalio-0.5.1-IZ96mLUOMuXAaGSDZxlxw
license:              LicenseRef-OtherLicense
copyright:            © 2013-2018 Stephen Paul Weber
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               Stephen Paul Weber <singpolyma@singpolyma.net>
stability:            experimental
homepage:             https://github.com/singpolyma/unexceptionalio
synopsis:             IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.

    It is intended that you use qualified imports with this library.

    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO

    You may also wish to investigate unexceptionalio-trans if you like
    monad transformers.

    Blog post: http://sngpl.ma/p4uT0

category:             Control
abi:                  c7e6b74aba6d92a8d76400fc701cf718
exposed:              True
exposed-modules:      UnexceptionalIO
import-dirs:          /usr/lib/ghc-9.0.2/site-local/unexceptionalio-0.5.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unexceptionalio-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/unexceptionalio-0.5.1
hs-libraries:         HSunexceptionalio-0.5.1-IZ96mLUOMuXAaGSDZxlxw
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock

haddock-html:         /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unexceptionalio-0.5.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unexceptionalio
version:              0.5.1
visibility:           public
id:                   unexceptionalio-0.5.1-GcYY4WOTCYcHCcS95HuZ7
key:                  unexceptionalio-0.5.1-GcYY4WOTCYcHCcS95HuZ7
license:              LicenseRef-OtherLicense
copyright:            © 2013-2018 Stephen Paul Weber
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               Stephen Paul Weber <singpolyma@singpolyma.net>
stability:            experimental
homepage:             https://github.com/singpolyma/unexceptionalio
synopsis:             IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.

    It is intended that you use qualified imports with this library.

    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO

    You may also wish to investigate unexceptionalio-trans if you like
    monad transformers.

    Blog post: http://sngpl.ma/p4uT0

category:             Control
abi:                  b8dac9fdd62e1b8ad0189fa353046b5f
exposed:              True
exposed-modules:      UnexceptionalIO
import-dirs:          /usr/lib/ghc-9.2.8/site-local/unexceptionalio-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unexceptionalio-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unexceptionalio
hs-libraries:         HSunexceptionalio-0.5.1-GcYY4WOTCYcHCcS95HuZ7
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock

haddock-html:         /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
